@@ -538,9 +538,11 @@ fn gen_skel_link_getter(
 
 fn open_bpf_object(name: &str, data: &[u8]) -> Result<*mut libbpf_sys::bpf_object> {
     let cname = CString::new(name)?;
-    let mut obj_opts = libbpf_sys::bpf_object_open_opts::default();
-    obj_opts.sz = std::mem::size_of::<libbpf_sys::bpf_object_open_opts>() as libbpf_sys::size_t;
-    obj_opts.object_name = cname.as_ptr();
+    let obj_opts = libbpf_sys::bpf_object_open_opts {
+        sz: std::mem::size_of::<libbpf_sys::bpf_object_open_opts>() as libbpf_sys::size_t,
+        object_name: cname.as_ptr(),
+        ..Default::default()
+    };
     let object = unsafe {
         libbpf_sys::bpf_object__open_mem(
             data.as_ptr() as *const c_void,
